| Safe Haskell | Safe-Inferred |
|---|
Data.Summary
Documentation
Many Monte Carlo simulations require statistical analysis of the results.
Any Result instances which can be described statistically should be made instances of Summary.
Methods
sampleMean :: s -> DoubleSource
Compute the mean of the aggregated observations
Compute the std. error of the aggregated observations
sampleVar :: s -> DoubleSource
Compute the variance of the aggregated observations
Compute the standard deviation of the aggregated observations
sampleSize :: s -> IntSource
Return the number of observations aggregated
Instances